summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteproperties.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteproperties.h')
-rw-r--r--kopete/libkopete/kopeteproperties.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/kopete/libkopete/kopeteproperties.h b/kopete/libkopete/kopeteproperties.h
index bfeaedea..24b7536f 100644
--- a/kopete/libkopete/kopeteproperties.h
+++ b/kopete/libkopete/kopeteproperties.h
@@ -17,7 +17,7 @@
#ifndef KOPETEPROPERTIES_H
#define KOPETEPROPERTIES_H
-#include <qasciidict.h>
+#include <tqasciidict.h>
#include <typeinfo>
@@ -77,8 +77,8 @@ public:
*
* \code
* SomeParent *propertyContainer = ...
- * Property<SomeParent,QString> &myProperty = ...
- * QString value = propertyContainer->property(myProperty);
+ * Property<SomeParent,TQString> &myProperty = ...
+ * TQString value = propertyContainer->property(myProperty);
* propertyContainer->setProperty(myProperty, "hello");
* \endcode
*
@@ -121,7 +121,7 @@ struct PropertyData
*/
class PropertyStorage
{
- typedef QAsciiDict<PropertyData> PropertyDict;
+ typedef TQAsciiDict<PropertyData> PropertyDict;
// setCustomPropertyData can be called on a const object, allowing the
// guarantee that DataProperty::data() never returns 0.
mutable PropertyDict _storage;
@@ -197,9 +197,9 @@ public:
template<class Parent>
struct UserVisible
{
- virtual QString userText( Parent * ) = 0;
- virtual QString label() = 0;
- virtual QString icon() = 0;
+ virtual TQString userText( Parent * ) = 0;
+ virtual TQString label() = 0;
+ virtual TQString icon() = 0;
};
/**
@@ -209,8 +209,8 @@ struct UserVisible
template<class Parent>
struct XMLSerializable
{
- virtual void fromXML( Parent *, const QDomElement & ) = 0;
- virtual void toXML( const Parent *, QDomElement & ) = 0;
+ virtual void fromXML( Parent *, const TQDomElement & ) = 0;
+ virtual void toXML( const Parent *, TQDomElement & ) = 0;
};
/**
@@ -220,8 +220,8 @@ struct XMLSerializable
template<class Parent>
struct StringSerializable
{
- virtual void fromString( Parent *, const QString & ) = 0;
- virtual QString toString( const Parent * ) = 0;
+ virtual void fromString( Parent *, const TQString & ) = 0;
+ virtual TQString toString( const Parent * ) = 0;
};
//END interfaces
@@ -297,12 +297,12 @@ public:
*/
/**
* Explicitly specialised for all types QVariant supports
*/
-template<class T> T variantTo(QVariant);
+template<class T> T variantTo(TQVariant);
-QVariant variantFromXML(const QDomElement&);
-void variantToXML(QVariant v, QDomElement &);
+TQVariant variantFromXML(const TQDomElement&);
+void variantToXML(TQVariant v, TQDomElement &);
/**
* @}
@@ -311,7 +311,7 @@ void variantToXML(QVariant v, QDomElement &);
/**
* @brief Convenience implementation of XMLSerializable in terms of QVariants
*
* This class provides XML serialization for data that can be stored in a QVariant. You
* will need to multiply-inherit from this class and (usually indirectly) from @ref Property.
*
* You can combine this class with other convenience classes such as SimpleDataProperty
@@ -319,8 +319,8 @@ void variantToXML(QVariant v, QDomElement &);
*
* \code
* class ContactNickNameProperty
- * : public SimpleDataProperty<Contact,QString>
- * , XMLProperty<ContactNickNameProperty,Contact,QString>
+ * : public SimpleDataProperty<Contact,TQString>
+ * , XMLProperty<ContactNickNameProperty,Contact,TQString>
* {
* public:
* const char *name() const { return "nickName"; }
@@ -331,13 +331,13 @@ template<class Derived, class Parent, typename Type>
class XMLProperty : public XMLSerializable<Parent>
{
public:
- void fromXML( Parent *t, const QDomElement &e )
+ void fromXML( Parent *t, const TQDomElement &e )
{
static_cast<Derived*>(this)->set(t, variantTo<Type>(variantFromXML(e)));
}
- void toXML( const Parent *t, QDomElement &e )
+ void toXML( const Parent *t, TQDomElement &e )
{
- variantToXML(QVariant(static_cast<Derived*>(this)->get(t)),e);
+ variantToXML(TQVariant(static_cast<Derived*>(this)->get(t)),e);
}
};
@@ -297,12 +297,12 @@ public:
*/
/**
- * Explicitly specialised for all types QVariant supports
+ * Explicitly specialised for all types TQVariant supports
*/
@@ -311,7 +311,7 @@ void variantToXML(QVariant v, QDomElement &);
* @brief Convenience implementation of XMLSerializable in terms of QVariants
*
- * This class provides XML serialization for data that can be stored in a QVariant. You
+ * This class provides XML serialization for data that can be stored in a TQVariant. You
* will need to multiply-inherit from this class and (usually indirectly) from @ref Property.
*